@@ -1,20 +1,24 @@
 import nonebot
 import os
 import asyncio
+import openai
 
 from nonebot import on_command
 from nonebot.params import CommandArg
 from nonebot.rule import to_me
 from nonebot.adapters.onebot.v11 import (Message, MessageSegment)
 from nonebot.adapters.onebot.v11 import MessageEvent
-# from aiohttp import ClientSession
+
 from .ChatSession import ChatSession
 
 try:
     api_key = nonebot.get_driver().config.openai_api_key
-    model_id = nonebot.get_driver().config.openai_model_name
 except:
     api_key = ""
+    
+try:
+    model_id = nonebot.get_driver().config.openai_model_name
+except:
     model_id = "gpt-3.5-turbo"
 
 try:
@@ -29,12 +33,15 @@ except:
 
 
 if http_proxy != "":
-    os.environ["http_proxy"] = http_proxy
-
+    # os.environ["http_proxy"] = http_proxy
+    # os.environ["https_proxy"] = http_proxy
+    proxy = {'http': http_proxy, 'https': http_proxy}
 
 session = {}
 
-chat_request = on_command("", rule=to_me(), block=True, priority=1)
+
+# 带上下文的聊天
+chat_request = on_command("/chat", block=True, priority=1)
 
 
 @chat_request.handle()
@@ -53,16 +60,56 @@ async def _(event: MessageEvent, msg: Message = CommandArg()):
         session[event.get_session_id()] = ChatSession(api_key=api_key, model_id=model_id, max_limit=max_limit)
 
     try:
-        # openai.aiosession.set(ClientSession())
-        # res = session[event.get_session_id()].get_response(content)
-        res = await loop.run_in_executor(None, session[event.get_session_id()].get_response, content)
-        # await openai.aiosession.get().close()
+        res = await session[event.get_session_id()].get_response(content,proxy)
 
     except Exception as error:
         await chat_request.finish(str(error), at_sender=True)
     await chat_request.finish(MessageSegment.text(res), at_sender=True)
 
 
+# 不带上下文的聊天
+chat_request2 = on_command("", rule=to_me(), block=True, priority=1)
+
+async def get_response(content,proxy):
+    openai.api_key = api_key
+    if proxy != "":
+        openai.proxy = proxy
+
+    res_ = await openai.ChatCompletion.acreate(
+        model=model_id,
+        messages=[
+            {"role": "user", "content": content}
+        ]
+    )
+
+    res = res_.choices[0].message.content
+
+    while res.startswith("\n") != res.startswith("？"):
+        res = res[1:]
+    print(res)
+
+    return res
+
+@chat_request2.handle()
+async def _(event: MessageEvent, msg: Message = CommandArg()):
+    print(event.get_session_id())
+    if api_key == "":
+        await chat_request2.finish(MessageSegment.text("请先配置openai_api_key"))
+
+    content = msg.extract_plain_text()
+    if content == "" or content is None:
+        await chat_request2.finish(MessageSegment.text("内容不能为空！"))
+
+    await chat_request2.send(MessageSegment.text("ChatGPT正在思考中......"))
+
+    try:
+        res = await get_response(content,proxy)
+
+    except Exception as error:
+        await chat_request2.finish(str(error))
+    await chat_request2.finish(MessageSegment.text(res))
+
+
 clear_request = on_command("/clear", block=True, priority=1)
 
 @clear_request.handle()
